Learn R Programming

ggborderline (version 0.2.0)

ggborderline-package: ggborderline: Line Plots that Pop

Description

logo

A set of geometries to make line plots a little bit nicer. Use along with 'ggplot2' to: - Improve the clarity of line plots with many overlapping lines - Draw more realistic worms.

Arguments

See Also