powered by
A set of geometries to make line plots a little bit nicer. Use along with 'ggplot2' to: - Improve the clarity of line plots with many overlapping lines - Draw more realistic worms.
Useful links:
https://github.com/wurli/ggborderline
https://wurli.github.io/ggborderline/